@@ -111,7 +111,7 @@ QStringList dependencies(const Object* o, const QStringList& scope)
             break;
     }
     
-    return ret.toList();
+    return ret.values();
 }
 
 bool hasTheVar(const QSet<QString> & vars, const Object * o)
@@ -640,7 +640,7 @@ QString generateDependencyGraph(const Variables* v)
         foreach(const QString& d, deps) {
             const Object* o=v->value(d);
             if(o && isLambda(o)) {
-                ret += "\t"+current+" -> "+d+";\n";
+                ret += '\t'+current+" -> "+d+";\n";
             }
         }
     }
