@@ -100,8 +100,9 @@ void AnalitzaTest::testTrivialCalculate_data()
     QTest::newRow("lambda")  << "(x->x+2)(2)" << Cn(4.);
     QTest::newRow("lambda2") << "(x->3*x^2)(1)" << Cn(3.);
     QTest::newRow("lambda3") << "(x->x*sum(t:t=0..3))(2)" << Cn(12.);
-    QTest::newRow("imaginarypow") << "(-4)^(1/4)" << Cn(1.);
+    QTest::newRow("imaginarypow") << "(-4)^(1/4)" << Cn(1, 1);
     QTest::newRow("imaginaryroot") << "root(-4, 4)" << Cn(1.);
+    QTest::newRow("squareroot-1") << "(-1)^(1/2)" << Cn(0, 1);
 
     //comprehension
     QTest::newRow("sum.2bvars") << "sum(x*y : (x, y)=1..3)" << Cn(36.);
@@ -668,6 +669,7 @@ void AnalitzaTest::testSimplify_data()
     QTest::newRow("poli4") << "-x-1-2-4" << "-x-7";
     QTest::newRow("poli4.0") << "-x-y-z" << "-x-y-z";
     QTest::newRow("poli4.1") << "minus(-x, 1, 2, 4)" << "-x-7";
+    QTest::newRow("poli5") << "y+3*(x-1)" << "y+3*(x-1)";
 //     QTest::newRow("powerscomb") << "3**x*3**x" << "9^x";
     QTest::newRow("no var") << "2+2" << "4";
     QTest::newRow("simple") << "x+x" << "2*x";
